@@ -11,6 +11,16 @@ def deserialize_json(method, _json):
         get_error(method, e)
 
 
+def deserialize_json_v2(method, _json):
+    if isinstance(_json, bytes):
+        _json = _json.decode("utf-8")
+
+    try:
+        return json.loads(_json)
+    except Exception as e:
+        get_error(method, e)
+
+
 def decode_json(method, js):
     try:
         return js.decode("utf-8")
@@ -374,7 +384,6 @@ def make_update_string_v2(payload, table, key, key_value):
 
 
 def make_insert_string_v3(payload: dict, table: str):
-
     _keys = "{}".format("".join("{}, ".format(e) for e in list(payload.keys())))[:-2]
     _values = ""
 
@@ -419,4 +428,53 @@ def make_insert_string_v3(payload: dict, table: str):
         keys=_keys,
         values=_values)
 
-    return _query
\ No newline at end of file
+    return _query
+
+
+def make_update_string_v3(payload, table, key, key_value):
+    string = ""
+
+    for name, value in payload.items():
+        if name != key:
+            if isinstance(value, str):
+                value = value.replace("'", "''")
+
+            if isinstance(value, dict):
+                if not value:
+                    string += "{} = '{}', ".format(name, "{}")
+                else:
+                    string += " {} = '{}', ".format(name, json.dumps(value))
+
+            elif isinstance(value, list):
+
+                value = [item.replace("'", "''") for item in value]
+
+                if is_list_of_jsons(value) and value:
+                    value = json.dumps(value).replace("[", "{'").replace("]", "'}")
+                    string += " {}, ".format(value)
+
+                else:
+                    value = json.dumps(value).replace("[", "{").replace("]", "}")
+                    string += " {} = '{}', ".format(name, value)
+
+            elif isinstance(value, bool):
+                string += " {} = '{}', ".format(name, value)
+
+            elif isinstance(value, int):
+                string += " {} = {}, ".format(name, value)
+
+            elif value is None:
+                string += " {} =  NULL, ".format(name)
+
+            else:
+                string += " {} = '{}', ".format(name, value)
+
+    update_string = (
+            "UPDATE " + table + " SET " + string[:-2]
+            + " WHERE " + key + " = '" + key_value + "'"
+    )
+
+    update_string = update_string.replace("'", "\'")
+    print("UPDATE STRING: " + update_string)
+
+    return update_string
